import React, { useRef, useState } from 'react';
import { StyleSheet, View, Text, TextInput } from 'react-native';
import { Theme } from '../Styles/theme';
import Icon from '../Icon';
const Search = props => {
    const [value, setValue] = useState('');
    const $input = useRef(null);
    const { shape = 'round', textAlign = 'left', placeholder, showClear = true, searchText = '搜索', showSearchText = true, textInputProps = {}, onSearch, onClear, } = props;
    const onSearchText = () => {
        console.log(value);
        onSearch && onSearch(value);
    };
    const onClearText = () => {
        setValue('');
        onClear && onClear();
    };
    return (React.createElement(View, { style: styles.searchContainer },
        React.createElement(View, { style: [styles.search, shape === 'round' && styles.round] },
            React.createElement(Icon, { name: "search", size: 22, color: Theme.colorTextPlaceholder }),
            React.createElement(TextInput, Object.assign({ ref: $input, style: styles.searchInput, placeholder: placeholder, textAlign: textAlign, placeholderTextColor: Theme.colorTextPlaceholder, returnKeyType: "search", blurOnSubmit: true, enablesReturnKeyAutomatically: true, multiline: false }, textInputProps, { value: value, onChangeText: setValue, onSubmitEditing: onSearchText })),
            showClear && !!value && (React.createElement(Icon, { name: "close-circle", size: 20, color: Theme.colorTextPlaceholder, onPress: onClearText }))),
        showSearchText && (React.createElement(View, { style: styles.searchTextWrap },
            React.createElement(Text, { style: styles.searchText, onPress: () => {
                    onSearchText();
                    $input.current?.blur();
                } }, searchText)))));
};
const styles = StyleSheet.create({
    searchContainer: {
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
    },
    search: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        borderColor: Theme.colorIconBase,
        borderWidth: 0.5,
        borderRadius: 4,
        paddingHorizontal: 6,
    },
    round: {
        borderRadius: 16,
    },
    searchInput: {
        flex: 1,
        padding: 0,
        marginLeft: 4,
        height: 32,
        fontSize: 14,
        color: Theme.colorTextParagraph,
    },
    searchTextWrap: {
        marginLeft: 8,
    },
    searchText: {
        fontSize: 18,
        color: Theme.colorLink,
    },
});
export default Search;
